@@ -1,12 +1,31 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-
+#
+# Copyright 2021 The NiPreps Developers <nipreps@gmail.com>
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
+# We support and encourage derived works from this project, please read
+# about our expectations at
+#
+#     https://www.nipreps.org/community/licensing/
+#
 from nipype.interfaces.base import (
-    File,
-    traits,
     CommandLine,
-    TraitedSpec,
     CommandLineInputSpec,
+    File,
+    TraitedSpec,
+    traits,
 )
 
 
@@ -31,7 +50,9 @@ class GCORInputSpec(CommandLineInputSpec):
         0, argstr="-nfirst %d", desc="specify number of initial TRs to ignore"
     )
     no_demean = traits.Bool(
-        False, argstr="-no_demean", desc="do not (need to) demean as first step"
+        False,
+        argstr="-no_demean",
+        desc="do not (need to) demean as first step",
     )
 
 
@@ -70,7 +91,8 @@ class GCOR(CommandLine):
             for line in runtime.stdout.split("\n")
             if line.strip().startswith("GCOR = ")
         ][-1]
-        setattr(self, "_gcor", float(gcor_line[len("GCOR = "):]))
+        str_len = len("GCOR = ")
+        setattr(self, "_gcor", float(gcor_line[str_len:]))
         return runtime
 
     def _list_outputs(self):
